 /**
  *   la classe gestisce le informazioni relative a uno studente
  *   quali nome, matricola, elenco degli esami sostenuti con relativa votazione
  *   @author Adriano Luchetta
  *   @version 03-Nov-2005
  *   @version 12-Nov-2004
  *   @see Esame.java
  */
  
public class Studente
{
   // parte privata
   private String nome;
   private String matr;
   private Esame[] esame; // elenco di oggetti di classe Esame
   private int esameSize; // tecnica dell'array riempito solo in parte

   // parte pubblica

   /**
      inizializza uno studente, con lista vuota di esami sostenuta
      @param unNome il nome di questo studente
      @param unaMatr la matricola di questo studente
      @throws IllegalArgumentException se uno dei due parametri ha valore null
   */
   public Studente (String unNome, String unaMatr)
   {
      // pre-condizioni
      if (unNome == null || unaMatr == null)
         throw new IllegalArgumentException();

      nome = unNome;
      matr = unaMatr;
      esame = new Esame[1];
      esameSize = 0;
   }

   /**
      aggiunge un esame nella lista degli esami dello studente
      @param unEsame l'esame da registrare
      @throws IllegalArgumentException se il parametro vale null
   */
   public void aggiungiEsame(Esame unEsame)
   {
      if (unEsame == null)
         throw new IllegalArgumentException();

      // stampa per debugging
      //System.out.println("aggiungoEsame: " + unEsame);

      // ridimensionamento dinamico dell'array
      if (esameSize >= esame.length)
      {
         Esame[] newEsame = new Esame[2 * esame.length];
         for (int i = 0; i < esame.length; i++)
            newEsame[i] = esame[i];

         esame = newEsame;
      }

      // inserimento dell'esame nella lista di esami
      esame[esameSize] = unEsame;
      esameSize++;
   }

   /**
      verifica se la lista di esami e' vuoto
      @return true se la lista di esami e' vuoto, false altrimenti
   */
   public boolean isEmpty()
   {
      return esameSize == 0;
   }

   /**
      calcola la meda dei voti conseguiti negli esami.
      @return la media dei voti, zero se la lista di esami e' vuota
   */
   public double media()
   {
      if (isEmpty())
         return 0;

      double sum = 0;
      for (int i = 0; i < esameSize; i++)
         sum += esame[i].getVoto();

      return sum / esameSize;
   }

   /**
      restituisce il numero di esami sostenuti
      @return il numero di esami sostenuti
   */
   public int numeroEsami()
   {
      return esameSize;
   }

   /**
      restituisce una stringa che contiene l'informazione relativa
      allo studente:
      <BR>
      esempio:
      <BR>
      matr.: 12345, nome: Bruno Biondo
      <BR>
      n. 2 esami sostenuti
      <BR>
      &nbsp;&nbsp;1) Matematica A: 21
      <BR>
      &nbsp;&nbsp;2) Fondamenti Informatica 1 : 23
      @return la stringa che descrive uno studente
   */
   public String toString()
   {
      String str = "matr.: " + matr + ", nome: " + nome + "\n";
      str = str + "n. " + numeroEsami() + " esami sostenuti\n";
      for (int i = 0; i < esameSize; i++)
          str = str + " " + (i+1) + ") " + esame[i] + "\n";

      return str + "\n";
   }
}
